@@ -1,4 +1,5 @@
 from moodle_dl.state_recorder.file import File
+from moodle_dl.download_service.path_tools import PathTools
 
 
 class Course:
@@ -14,13 +15,13 @@ class Course:
         message = 'Course ('
 
         message += 'id: %s' % (self.id)
-        message += ', fullname: %s' % (self.fullname)
-        message += ', overwrite_name_with: %s' % (self.overwrite_name_with)
+        message += ', fullname: "%s"' % (PathTools.to_valid_name(self.fullname))
+        message += ', overwrite_name_with: "%s"' % (PathTools.to_valid_name(self.overwrite_name_with))
         message += ', create_directory_structure: %s' % (self.create_directory_structure)
         message += ', files: %s' % (len(self.files))
 
-        for i, file in enumerate(self.files):
-            message += ', file[%i]: %s' % (i, file)
+        # for i, file in enumerate(self.files):
+        #     message += ', file[%i]: %s' % (i, file)
 
         message += ')'
         return message
