@@ -202,6 +202,15 @@ class StateRecorder:
             and file1.hash != file2.hash
         ):
             return True
+
+        if (
+            file1.content_type == 'description-url'
+            and file1.content_type == file2.content_type
+            and file1.content_fileurl != file2.content_fileurl
+            # One consideration: or file1.section_name != file2.section_name)
+            # But useless if description-links in the course must be unique anyway
+        ):
+            return True
         return False
 
     def __file_was_moved(self, file1: File, file2: File) -> bool:
